@@ -6,6 +6,7 @@
 #include "dbus/applicationmanager1adaptor.h"
 #include "applicationservice.h"
 #include "dbus/AMobjectmanager1adaptor.h"
+#include "global.h"
 #include "systemdsignaldispatcher.h"
 #include "propertiesForwarder.h"
 #include "applicationHooks.h"
@@ -14,7 +15,6 @@
 #include <QHash>
 #include <QDBusMessage>
 #include <QStringBuilder>
-#include <chrono>
 #include <unistd.h>
 
 ApplicationManager1Service::~ApplicationManager1Service() = default;
@@ -179,7 +179,7 @@ void ApplicationManager1Service::initService(QDBusConnection &connection) noexce
             app->Launch({}, {}, {}, realExec);
         }
     } else {
-         constexpr auto XSettings = "org.deepin.dde.XSettings1";
+        constexpr auto XSettings = "org.deepin.dde.XSettings1";
 
         auto *watcher = new (std::nothrow)
             QDBusServiceWatcher{XSettings, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, this};
@@ -202,8 +202,8 @@ void ApplicationManager1Service::initService(QDBusConnection &connection) noexce
             *sigCon = connect(watcher, &QDBusServiceWatcher::serviceRegistered, singleSlot);
         }
 
-        auto msg =
-            QDBusMessage::createMethodCall("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus", "NameHasOwner");
+        auto msg = QDBusMessage::createMethodCall(
+            "org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus", "NameHasOwner");
         msg << XSettings;
 
         auto reply = QDBusConnection::sessionBus().call(msg);
@@ -287,10 +287,7 @@ void ApplicationManager1Service::removeInstanceFromApplication(const QString &un
 
 void ApplicationManager1Service::scanMimeInfos() noexcept
 {
-    QStringList dirs;
-    dirs.append(getXDGConfigDirs());
-    dirs.append(getDesktopFileDirs());
-
+    const auto& dirs = getMimeDirs();
     for (const auto &dir : dirs) {
         auto info = MimeInfo::createMimeInfo(dir);
         if (info) {
@@ -376,7 +373,6 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
 
     for (auto &it : autostartItems) {
         auto desktopFile = std::move(it.second);
-
         DesktopFileGuard guard{desktopFile};
         if (!guard.try_open()) {
             continue;
@@ -391,7 +387,6 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
             continue;
         }
 
-        QString originalSource;
         QSharedPointer<ApplicationService> app{nullptr};
         auto asApplication = tmp.value(DesktopFileEntryKey, X_Deepin_GenerateSource).value_or(DesktopEntry::Value{});
         auto shouldLaunch = tmp.value(DesktopFileEntryKey, DesktopEntryHidden).value_or(DesktopEntry::Value{});
@@ -400,9 +395,9 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
         if (!asApplication.isNull()) {  // modified by application manager
             auto appSource = asApplication.toString();
 
-            QFileInfo sourceInfo{appSource};
-            if ((!sourceInfo.exists() or !sourceInfo.isFile()) and !file.remove()) {
-                qWarning() << "remove invalid autostart file error:" << file.error();
+            const QFileInfo sourceInfo{appSource};
+            if (!sourceInfo.exists() || !sourceInfo.isFile()) {
+                qWarning() << "autostart file" << appSource << "doesn't exist, skip.";
                 continue;
             }
 
@@ -427,18 +422,14 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
                 continue;
             }
 
-            originalSource = appSource;
-        }
-
-        originalSource = originalSource.isNull() ? desktopFile.sourcePath() : originalSource;
-        if (app) {
+            app->setAutostartSource({desktopFile.sourcePath(), std::move(tmp)});
             if (autostartFlag) {
-                auto realExec = tmp.value(DesktopFileEntryKey, "Exec").value_or(QString{""}).toString();
+                auto val = tmp.value(DesktopFileEntryKey, "Exec").value_or(DesktopEntry::Value{});
+                auto realExec = val.isNull() ? QString{} : val.toString();
                 qInfo() << "launch autostart application " << app->id() << " by " << realExec;
                 ret.insert(app, realExec);
             }
 
-            app->setAutostartSource({std::move(originalSource), std::move(tmp)});
             continue;
         }
 
@@ -450,22 +441,25 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
 
         if (auto existApp = m_applicationList.value(desktopFile.desktopId()); existApp) {
             if (autostartFlag) {
-                auto realExec = tmp.value(DesktopFileEntryKey, "Exec").value_or(QString{""}).toString();
+                auto val = tmp.value(DesktopFileEntryKey, "Exec").value_or(DesktopEntry::Value{});
+                auto realExec = val.isNull() ? QString{} : val.toString();
                 qInfo() << "launch exist autostart application " << existApp->id() << " by " << realExec;
                 ret.insert(existApp, realExec);
             }
-            existApp->setAutostartSource({std::move(originalSource), std::move(tmp)});
+
+            existApp->setAutostartSource({desktopFile.sourcePath(), std::move(tmp)});
             continue;
         }
 
         guard.close();
         // new application
+        auto originalSource = desktopFile.sourcePath();
         app = addApplication(std::move(desktopFile));
         if (!app) {
             qWarning() << "add autostart application failed, skip.";
             continue;
         }
-        app->setAutostartSource({std::move(originalSource), {}});
+        app->setAutostartSource({originalSource, {}});
 
         if (autostartFlag) {
             qInfo() << "launch new autostart application " << app->id();
@@ -478,7 +472,7 @@ QHash<QSharedPointer<ApplicationService>, QString> ApplicationManager1Service::s
 
 void ApplicationManager1Service::loadHooks() noexcept
 {
-    auto hookDirs = getXDGDataDirs();
+    auto hookDirs = getXDGDataMergedDirs();
     std::for_each(hookDirs.begin(), hookDirs.end(), [](QString &str) { str.append(ApplicationManagerHookDir); });
     QHash<QString, ApplicationHook> hooks;
 
@@ -581,7 +575,6 @@ QString ApplicationManager1Service::Identify(const QDBusUnixFileDescriptor &pidf
     Q_ASSERT_X(static_cast<bool>(m_identifier), "Identify", "Broken Identifier.");
 
     const auto ret = m_identifier->Identify(pidfd);
-    
     if (ret.ApplicationId.isEmpty()) {
         safe_sendErrorReply(QDBusError::Failed, "Identify failed.");
         return {};
@@ -656,8 +649,7 @@ void ApplicationManager1Service::doReloadApplications()
     qInfo() << "reload applications.";
 
     auto desktopFileDirs = getDesktopFileDirs();
-    desktopFileDirs.append(getAutoStartDirs());  // detect autostart apps add/remove/update
-
+    desktopFileDirs.append(getXDGConfigDirs());
     auto appIds = m_applicationList.keys();
 
     applyIteratively(
@@ -670,10 +662,8 @@ void ApplicationManager1Service::doReloadApplications()
             }
 
             auto file = std::move(ret).value();
-
-            QSharedPointer<ApplicationService> app = m_applicationList.value(file.desktopId());
-
-            if (app and appIds.contains(app->id())) {
+            auto app = m_applicationList.value(file.desktopId());
+            if (app && appIds.contains(app->id())) {
                 // Can emit correct remove signal when uninstalling applications
                 if (ApplicationFilter::tryExecCheck(*(app.data()->m_entry))) {
                     qDebug() << info.absolutePath() << "Checked TryExec failed and will be removed";
@@ -697,7 +687,6 @@ void ApplicationManager1Service::doReloadApplications()
 
     m_mimeManager->reset();
     scanMimeInfos();
-
     scanAutoStart();
 }
 
@@ -726,7 +715,7 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
         return {};
     }
 
-    //传入的desktop文件内容为空的时候直接返回。
+    // 传入的desktop文件内容为空的时候直接返回。
     QString errMsg;
     auto fileContent = DesktopFileGenerator::generate(desktop_file, errMsg);
     if (fileContent.isEmpty() or !errMsg.isEmpty()) {
@@ -741,7 +730,7 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
         return {};
     }
 
-    //判断当前是否已经存在了desktop文件
+    // 判断当前是否已经存在了desktop文件
     xdgDataHome.setPath(dir);
     const auto &filePath = xdgDataHome.filePath(name);
     QFile file{filePath};
@@ -750,10 +739,10 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
 
     if (fileExists) {
         ParserError parseErr{ParserError::NoError};
-        //判断desktop文件内容是否合法
+        // 判断desktop文件内容是否合法
         auto existingDesktopFile = DesktopFile::searchDesktopFileByPath(filePath, parseErr);
         if (existingDesktopFile) {
-            //解析当前已经存在的desktop文件内容
+            // 解析当前已经存在的desktop文件内容
             DesktopEntry entry;
             ParserError entryErr = entry.parse(existingDesktopFile.value());
             if (entryErr != ParserError::NoError) {
@@ -767,7 +756,7 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
     if (fileExists && shouldRewrite) {
         openMode |= QFile::Truncate;  // 清空现有内容
     } else if (!fileExists) {
-        openMode |= QFile::NewOnly;   // 只创建新文件
+        openMode |= QFile::NewOnly;  // 只创建新文件
     }
 
     if (!file.open(openMode)) {
@@ -808,13 +797,11 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
     }
 
     m_mimeManager->updateMimeCache(dir);
-
     return appId;
 }
 
-
 void ApplicationManager1Service::deleteUserApplication(const QString &app_id) noexcept
-{ 
+{
     if (app_id.isEmpty()) {
         safe_sendErrorReply(QDBusError::Failed, "app id name is empty.");
         return;
@@ -828,29 +815,27 @@ void ApplicationManager1Service::deleteUserApplication(const QString &app_id) no
     }
 
     xdgDataHome.setPath(dir);
-    const auto &filePath = xdgDataHome.filePath(app_id+".desktop");
+    const auto &filePath = xdgDataHome.filePath(app_id + ".desktop");
 
     if (QFileInfo info{filePath}; !info.exists() || !info.isFile()) {
         safe_sendErrorReply(QDBusError::Failed, QString{"file not exists:%1"}.arg(info.absoluteFilePath()));
         return;
     }
 
-/*
-    auto apps = findApplicationsByIds({app_id});
-    if (apps.isEmpty()) {
-        qWarning() << "we can't find corresponding application in ApplicationManagerService.";
-    }
+    /*
+        auto apps = findApplicationsByIds({app_id});
+        if (apps.isEmpty()) {
+            qWarning() << "we can't find corresponding application in ApplicationManagerService.";
+        }
 
-    for (const auto &app : apps) {
-        app->setMimeTypes({});
-    }
-*/
+        for (const auto &app : apps) {
+            app->setMimeTypes({});
+        }
+    */
     if (!QFile::remove(filePath)) {
         safe_sendErrorReply(QDBusError::Failed, "remove file failed.");
         return;
     }
 
     m_mimeManager->updateMimeCache(dir);
-
-    return;
-}
\ No newline at end of file
+}
